////////////////////////////////////////////////////////////////////////////////////////////////////
//  Copyright www.aris.org.cn JamesTaylor
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//        http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
////////////////////////////////////////////////////////////////////////////////////////////////////
import "package:flutter/material.dart";

/// 默认使用语言
final Locale defaultLocale = Locale("en", "US");

/// 中国区域对象
final Locale localeChina = Locale("zh", "CN");

/// 支持的语言
Map<String, Locale> supportedLanguageLocaleMap = {
  "zh": Locale("zh", "CN"),
  "en": Locale("en"),
  "es": Locale("es"),
  "ko": Locale("ko")
};

/// 所有国家地区代码
List<Map<String, String>> codes = [
  {
    "name": "افغانستان",
    "code": "AF",
    "countryName": "Afghanistan",
    "dialCode": "+93",
  },
  {
    "name": "Åland",
    "code": "AX",
    "countryName": "Aland",
    "dialCode": "+358",
  },
  {
    "name": "Shqipëria",
    "code": "AL",
    "countryName": "Albania",
    "dialCode": "+355",
  },
  {
    "name": "الجزائر",
    "code": "DZ",
    "countryName": "Algeria",
    "dialCode": "+213",
  },
  {
    "name": "American Samoa",
    "code": "AS",
    "countryName": "American Samoa",
    "dialCode": "+1684",
  },
  {
    "name": "Andorra",
    "code": "AD",
    "countryName": "Andorra",
    "dialCode": "+376",
  },
  {
    "name": "Angola",
    "code": "AO",
    "countryName": "Angola",
    "dialCode": "+244",
  },
  {
    "name": "Anguilla",
    "code": "AI",
    "countryName": "Anguilla",
    "dialCode": "+1264",
  },
  {
    "name": "Antarctica",
    "code": "AQ",
    "countryName": "Antarctica",
    "dialCode": "+672",
  },
  {
    "name": "Antigua and Barbuda",
    "code": "AG",
    "countryName": "Antigua and Barbuda",
    "dialCode": "+1268",
  },
  {
    "name": "Argentina",
    "code": "AR",
    "countryName": "Argentina",
    "dialCode": "+54",
  },
  {
    "name": "Հայաստան",
    "code": "AM",
    "countryName": "Armenia",
    "dialCode": "+374",
  },
  {
    "name": "Aruba",
    "code": "AW",
    "countryName": "Aruba",
    "dialCode": "+297",
  },
  {
    "name": "Australia",
    "code": "AU",
    "countryName": "Australia",
    "dialCode": "+61",
  },
  {
    "name": "Österreich",
    "code": "AT",
    "countryName": "Austria",
    "dialCode": "+43",
  },
  {
    "name": "Azərbaycan",
    "code": "AZ",
    "countryName": "Azerbaijan",
    "dialCode": "+994",
  },
  {
    "name": "Bahamas",
    "code": "BS",
    "countryName": "Bahamas",
    "dialCode": "+1242",
  },
  {
    "name": "‏البحرين",
    "code": "BH",
    "countryName": "Bahrain",
    "dialCode": "+973",
  },
  {
    "name": "Bangladesh",
    "code": "BD",
    "countryName": "Bangladesh",
    "dialCode": "+880",
  },
  {
    "name": "Barbados",
    "code": "BB",
    "countryName": "Barbados",
    "dialCode": "+1246",
  },
  {
    "name": "Белару́сь",
    "code": "BY",
    "countryName": "Belarus",
    "dialCode": "+375",
  },
  {
    "name": "België",
    "code": "BE",
    "countryName": "Belgium",
    "dialCode": "+32",
  },
  {
    "name": "Belize",
    "code": "BZ",
    "countryName": "Belize",
    "dialCode": "+501",
  },
  {
    "name": "Bénin",
    "code": "BJ",
    "countryName": "Benign",
    "dialCode": "+229",
  },
  {
    "name": "Bermuda",
    "code": "BM",
    "countryName": "Bermuda",
    "dialCode": "+1441",
  },
  {
    "name": "ʼbrug-yul",
    "code": "BT",
    "countryName": "Bhutan",
    "dialCode": "+975",
  },
  {
    "name": "Bolivia",
    "code": "BO",
    "countryName": "Bolivia",
    "dialCode": "+591",
  },
  {
    "name": "Bosna i Hercegovina",
    "code": "BA",
    "countryName": "Bosnia and Herzegovina",
    "dialCode": "+387",
  },
  {
    "name": "Botswana",
    "code": "BW",
    "countryName": "Botswana",
    "dialCode": "+267",
  },
  {
    "name": "Bouvetøya",
    "code": "BV",
    "countryName": "Norway",
    "dialCode": "+47",
  },
  {
    "name": "Brasil",
    "code": "BR",
    "countryName": "Brazil",
    "dialCode": "+55",
  },
  {
    "name": "British Indian Ocean Territory",
    "code": "IO",
    "countryName": "British Indian Ocean Territory",
    "dialCode": "+246",
  },
  {
    "name": "Negara Brunei Darussalam",
    "code": "BN",
    "countryName": "Brunei Darussalam	",
    "dialCode": "+673",
  },
  {
    "name": "България",
    "code": "BG",
    "countryName": "Bulgaria",
    "dialCode": "+359",
  },
  {
    "name": "Burkina Faso",
    "code": "BF",
    "countryName": "Burkina Faso",
    "dialCode": "+226",
  },
  {
    "name": "Burundi",
    "code": "BI",
    "countryName": "Burundi",
    "dialCode": "+257",
  },
  {
    "name": "Cambodia",
    "code": "KH",
    "countryName": "Cambodia",
    "dialCode": "+855",
  },
  {
    "name": "Cameroon",
    "code": "CM",
    "countryName": "Cameroon",
    "dialCode": "+237",
  },
  {
    "name": "Canada",
    "code": "CA",
    "countryName": "Canada",
    "dialCode": "+1",
  },
  {
    "name": "Cabo Verde",
    "code": "CV",
    "countryName": "Cape Verde",
    "dialCode": "+238",
  },
  {
    "name": "Cayman Islands",
    "code": "KY",
    "countryName": "Cayman Islands",
    "dialCode": "+1345",
  },
  {
    "name": "Ködörösêse tî Bêafrîka",
    "code": "CF",
    "countryName": "Central African Republic",
    "dialCode": "+236",
  },
  {
    "name": "Tchad",
    "code": "TD",
    "countryName": "Chad",
    "dialCode": "+235",
  },
  {
    "name": "Chile",
    "code": "CL",
    "countryName": "Chile",
    "dialCode": "+56",
  },
  {
    "name": "中国大陆",
    "code": "CN",
    "countryName": "China",
    "dialCode": "+86",
  },
  {
    "name": "Christmas Island",
    "code": "CX",
    "countryName": "Christmas Island",
    "dialCode": "+61",
  },
  {
    "name": "Cocos (Keeling) Islands",
    "code": "CC",
    "countryName": "Cocos (Keeling) Islands",
    "dialCode": "+61",
  },
  {
    "name": "Colombia",
    "code": "CO",
    "countryName": "Colombia",
    "dialCode": "+57",
  },
  {
    "name": "Komori",
    "code": "KM",
    "countryName": "Comoros",
    "dialCode": "+269",
  },
  {
    "name": "République du Congo",
    "code": "CG",
    "countryName": "The Republic of the Congo",
    "dialCode": "+242",
  },
  {
    "name": "République démocratique du Congo",
    "code": "CD",
    "countryName": "The Democratic Republic of the Congo",
    "dialCode": "+243",
  },
  {
    "name": "Cook Islands",
    "code": "CK",
    "countryName": "Cook Islands",
    "dialCode": "+682",
  },
  {
    "name": "Costa Rica",
    "code": "CR",
    "countryName": "Costa Rica",
    "dialCode": "+506",
  },
  {
    "name": "Côte d'Ivoire",
    "code": "CI",
    "countryName": "Cote d'Ivoire",
    "dialCode": "+225",
  },
  {
    "name": "Hrvatska",
    "code": "HR",
    "countryName": "Croatia",
    "dialCode": "+385",
  },
  {
    "name": "Cuba",
    "code": "CU",
    "countryName": "Cuba",
    "dialCode": "+53",
  },
  {
    "name": "Κύπρος",
    "code": "CY",
    "countryName": "Cyprus",
    "dialCode": "+357",
  },
  {
    "name": "Česká republika",
    "code": "CZ",
    "countryName": "Czech Republic",
    "dialCode": "+420",
  },
  {
    "name": "Danmark",
    "code": "DK",
    "countryName": "Denmark",
    "dialCode": "+45",
  },
  {
    "name": "Djibouti",
    "code": "DJ",
    "countryName": "Djibouti",
    "dialCode": "+253",
  },
  {
    "name": "Dominica",
    "code": "DM",
    "countryName": "Dominica",
    "dialCode": "+1767",
  },
  {
    "name": "República Dominicana",
    "code": "DO",
    "countryName": "Dominican Republic",
    "dialCode": "+1809",
  },
  {
    "name": "Ecuador",
    "code": "EC",
    "countryName": "Ecuador",
    "dialCode": "+593",
  },
  {
    "name": "مصر‎",
    "code": "EG",
    "countryName": "Egypt",
    "dialCode": "+20",
  },
  {
    "name": "El Salvador",
    "code": "SV",
    "countryName": "El Salvador",
    "dialCode": "+503",
  },
  {
    "name": "Guinea Ecuatorial",
    "code": "GQ",
    "countryName": "Equatorial Guinea",
    "dialCode": "+240",
  },
  {
    "name": "ኤርትራ",
    "code": "ER",
    "countryName": "Eritrea",
    "dialCode": "+291",
  },
  {
    "name": "Eesti",
    "code": "EE",
    "countryName": "Estonia",
    "dialCode": "+372",
  },
  {
    "name": "ኢትዮጵያ",
    "code": "ET",
    "countryName": "Ethiopia",
    "dialCode": "+251",
  },
  {
    "name": "Falkland Islands",
    "code": "FK",
    "countryName": "Falkland Islands",
    "dialCode": "+500",
  },
  {
    "name": "Føroyar",
    "code": "FO",
    "countryName": "Faroe Islands",
    "dialCode": "+298",
  },
  {
    "name": "Fiji",
    "code": "FJ",
    "countryName": "Fiji",
    "dialCode": "+679",
  },
  {
    "name": "Suomi",
    "code": "FI",
    "countryName": "Finland",
    "dialCode": "+358",
  },
  {
    "name": "France",
    "code": "FR",
    "countryName": "France",
    "dialCode": "+33",
  },
  {
    "name": "Guyane française",
    "code": "GF",
    "countryName": "French Guiana",
    "dialCode": "+594",
  },
  {
    "name": "Polynésie française",
    "code": "PF",
    "countryName": "French Polynesia",
    "dialCode": "+689",
  },
  {
    "name": "Territoire des Terres australes et antarctiques fr",
    "code": "TF",
    "countryName": "Territory of the Southern and Antarctic Lands",
    "dialCode": "+262",
  },
  {
    "name": "Gabon",
    "code": "GA",
    "countryName": "Gabon",
    "dialCode": "+241",
  },
  {
    "name": "Gambia",
    "code": "GM",
    "countryName": "Gambia",
    "dialCode": "+220",
  },
  {
    "name": "საქართველო",
    "code": "GE",
    "countryName": "Georgia",
    "dialCode": "+995",
  },
  {
    "name": "Deutschland",
    "code": "DE",
    "countryName": "Germany",
    "dialCode": "+49",
  },
  {
    "name": "Ghana",
    "code": "GH",
    "countryName": "Ghana",
    "dialCode": "+233",
  },
  {
    "name": "Gibraltar",
    "code": "GI",
    "countryName": "Gibraltar",
    "dialCode": "+350",
  },
  {
    "name": "Ελλάδα",
    "code": "GR",
    "countryName": "Greece",
    "dialCode": "+30",
  },
  {
    "name": "Kalaallit Nunaat",
    "code": "GL",
    "countryName": "Greenland",
    "dialCode": "+299",
  },
  {
    "name": "Grenada",
    "code": "GD",
    "countryName": "Grenada",
    "dialCode": "+1473",
  },
  {
    "name": "Guadeloupe",
    "code": "GP",
    "countryName": "Guadeloupe",
    "dialCode": "+590",
  },
  {
    "name": "Guam",
    "code": "GU",
    "countryName": "Guam",
    "dialCode": "+1671",
  },
  {
    "name": "Guatemala",
    "code": "GT",
    "countryName": "Guatemala",
    "dialCode": "+502",
  },
  {
    "name": "Guernsey",
    "code": "GG",
    "countryName": "Guernsey",
    "dialCode": "+44",
  },
  {
    "name": "Guinée",
    "code": "GN",
    "countryName": "Guinea",
    "dialCode": "+224",
  },
  {
    "name": "Guiné-Bissau",
    "code": "GW",
    "countryName": "Guinea-Bissau",
    "dialCode": "+245",
  },
  {
    "name": "Guyana",
    "code": "GY",
    "countryName": "Guyana",
    "dialCode": "+592",
  },
  {
    "name": "Haïti",
    "code": "HT",
    "countryName": "Haiti",
    "dialCode": "+509",
  },
  {
    "name": "Heard Island and McDonald Islands",
    "code": "HM",
    "countryName": "Heard Island and McDonald Islands",
    "dialCode": "+0",
  },
  {
    "name": "Vaticano",
    "code": "VA",
    "countryName": "Holy See",
    "dialCode": "+379",
  },
  {
    "name": "Honduras",
    "code": "HN",
    "countryName": "Honduras",
    "dialCode": "+504",
  },
  {
    "name": "中国香港",
    "code": "HK",
    "countryName": "Hong Kong",
    "dialCode": "+852",
  },
  {
    "name": "Magyarország",
    "code": "HU",
    "countryName": "Hungary",
    "dialCode": "+36",
  },
  {
    "name": "Ísland",
    "code": "IS",
    "countryName": "Iceland",
    "dialCode": "+354",
  },
  {
    "name": "भारत",
    "code": "IN",
    "countryName": "India",
    "dialCode": "+91",
  },
  {
    "name": "Indonesia",
    "code": "ID",
    "countryName": "Indonesia",
    "dialCode": "+62",
  },
  {
    "name": "ایران",
    "code": "IR",
    "countryName": "Iran",
    "dialCode": "+98",
  },
  {
    "name": "العراق",
    "code": "IQ",
    "countryName": "Iraq",
    "dialCode": "+964",
  },
  {
    "name": "Éire",
    "code": "IE",
    "countryName": "Ireland",
    "dialCode": "+353",
  },
  {
    "name": "Isle of Man",
    "code": "IM",
    "countryName": "Isle of Man",
    "dialCode": "+44",
  },
  {
    "name": "ישראל",
    "code": "IL",
    "countryName": "Israel",
    "dialCode": "+972",
  },
  {
    "name": "Italia",
    "code": "IT",
    "countryName": "Italy",
    "dialCode": "+39",
  },
  {
    "name": "Jamaica",
    "code": "JM",
    "countryName": "Jamaica",
    "dialCode": "+1876",
  },
  {
    "name": "日本",
    "code": "JP",
    "countryName": "Japan",
    "dialCode": "+81",
  },
  {
    "name": "Jersey",
    "code": "JE",
    "countryName": "Jersey",
    "dialCode": "+44",
  },
  {
    "name": "الأردن",
    "code": "JO",
    "countryName": "Jordan",
    "dialCode": "+962",
  },
  {
    "name": "Қазақстан",
    "code": "KZ",
    "countryName": "Kazakhstan",
    "dialCode": "+7",
  },
  {
    "name": "Kenya",
    "code": "KE",
    "countryName": "Kenya",
    "dialCode": "+254",
  },
  {
    "name": "Kiribati",
    "code": "KI",
    "countryName": "Kiribati",
    "dialCode": "+686",
  },
  {
    "name": "북한",
    "code": "KP",
    "countryName": "North Korea",
    "dialCode": "+850",
  },
  {
    "name": "대한민국",
    "code": "KR",
    "countryName": "South Korea",
    "dialCode": "+82",
  },
  {
    "name": "Republika e Kosovës",
    "code": "XK",
    "countryName": "Republic of Kosovo",
    "dialCode": "+383",
  },
  {
    "name": "الكويت",
    "code": "KW",
    "countryName": "Kuwait",
    "dialCode": "+965",
  },
  {
    "name": "Кыргызстан",
    "code": "KG",
    "countryName": "Kyrgyzstan",
    "dialCode": "+996",
  },
  {
    "name": "ສປປລາວ",
    "code": "LA",
    "countryName": "Laos",
    "dialCode": "+856",
  },
  {
    "name": "Latvija",
    "code": "LV",
    "countryName": "Latvia",
    "dialCode": "+371",
  },
  {
    "name": "لبنان",
    "code": "LB",
    "countryName": "Lebanon",
    "dialCode": "+961",
  },
  {
    "name": "Lesotho",
    "code": "LS",
    "countryName": "Lesotho",
    "dialCode": "+266",
  },
  {
    "name": "Liberia",
    "code": "LR",
    "countryName": "Liberia",
    "dialCode": "+231",
  },
  {
    "name": "‏ليبيا",
    "code": "LY",
    "countryName": "Libya",
    "dialCode": "+218",
  },
  {
    "name": "Liechtenstein",
    "code": "LI",
    "countryName": "Liechtenstein",
    "dialCode": "+423",
  },
  {
    "name": "Lietuva",
    "code": "LT",
    "countryName": "Lithuania",
    "dialCode": "+370",
  },
  {
    "name": "Luxembourg",
    "code": "LU",
    "countryName": "Luxembourg",
    "dialCode": "+352",
  },
  {
    "name": "中国澳门",
    "code": "MO",
    "countryName": "Macao",
    "dialCode": "+853",
  },
  {
    "name": "Македонија",
    "code": "MK",
    "countryName": "The Republic of North Macedonia",
    "dialCode": "+389",
  },
  {
    "name": "Madagasikara",
    "code": "MG",
    "countryName": "Madagascar",
    "dialCode": "+261",
  },
  {
    "name": "Malawi",
    "code": "MW",
    "countryName": "Malawi",
    "dialCode": "+265",
  },
  {
    "name": "Malaysia",
    "code": "MY",
    "countryName": "Malaysia",
    "dialCode": "+60",
  },
  {
    "name": "Maldives",
    "code": "MV",
    "countryName": "Maldives",
    "dialCode": "+960",
  },
  {
    "name": "Mali",
    "code": "ML",
    "countryName": "Mali",
    "dialCode": "+223",
  },
  {
    "name": "Malta",
    "code": "MT",
    "countryName": "Malta",
    "dialCode": "+356",
  },
  {
    "name": "M̧ajeļ",
    "code": "MH",
    "countryName": "Marshall Islands",
    "dialCode": "+692",
  },
  {
    "name": "Martinique",
    "code": "MQ",
    "countryName": "Martinique",
    "dialCode": "+596",
  },
  {
    "name": "موريتانيا",
    "code": "MR",
    "countryName": "Mauritania",
    "dialCode": "+222",
  },
  {
    "name": "Maurice",
    "code": "MU",
    "countryName": "Mauritius",
    "dialCode": "+230",
  },
  {
    "name": "Mayotte",
    "code": "YT",
    "countryName": "Reunion",
    "dialCode": "+262",
  },
  {
    "name": "México",
    "code": "MX",
    "countryName": "Mexico",
    "dialCode": "+52",
  },
  {
    "name": "Micronesia",
    "code": "FM",
    "countryName": "Federated States of Micronesia",
    "dialCode": "+691",
  },
  {
    "name": "Moldova",
    "code": "MD",
    "countryName": "Moldova",
    "dialCode": "+373",
  },
  {
    "name": "Monaco",
    "code": "MC",
    "countryName": "Monaco",
    "dialCode": "+377",
  },
  {
    "name": "Монгол улс",
    "code": "MN",
    "countryName": "Mongolia",
    "dialCode": "+976",
  },
  {
    "name": "Црна Гора",
    "code": "ME",
    "countryName": "Montenegro",
    "dialCode": "+382",
  },
  {
    "name": "Montserrat",
    "code": "MS",
    "countryName": "Montserrat",
    "dialCode": "+1664",
  },
  {
    "name": "المغرب",
    "code": "MA",
    "countryName": "Morocco",
    "dialCode": "+212",
  },
  {
    "name": "Moçambique",
    "code": "MZ",
    "countryName": "Mozambique",
    "dialCode": "+258",
  },
  {
    "name": "Myanmar",
    "code": "MM",
    "countryName": "Burma",
    "dialCode": "+95",
  },
  {
    "name": "Namibia",
    "code": "NA",
    "countryName": "Namibia",
    "dialCode": "+264",
  },
  {
    "name": "Nauru",
    "code": "NR",
    "countryName": "Nauru",
    "dialCode": "+674",
  },
  {
    "name": "नपल",
    "code": "NP",
    "countryName": "Nepal",
    "dialCode": "+977",
  },
  {
    "name": "Nederland",
    "code": "NL",
    "countryName": "Netherlands",
    "dialCode": "+31",
  },
  {
    "name": "Netherlands Antilles",
    "code": "AN",
    "countryName": "Netherlands Antilles",
    "dialCode": "+599",
  },
  {
    "name": "Nouvelle-Calédonie",
    "code": "NC",
    "countryName": "New Caledonia",
    "dialCode": "+687",
  },
  {
    "name": "New Zealand",
    "code": "NZ",
    "countryName": "New Zealand",
    "dialCode": "+64",
  },
  {
    "name": "Nicaragua",
    "code": "NI",
    "countryName": "Nicaragua",
    "dialCode": "+505",
  },
  {
    "name": "Niger",
    "code": "NE",
    "countryName": "Niger",
    "dialCode": "+227",
  },
  {
    "name": "Nigeria",
    "code": "NG",
    "countryName": "Nigeria",
    "dialCode": "+234",
  },
  {
    "name": "Niuē",
    "code": "NU",
    "countryName": "Niue",
    "dialCode": "+683",
  },
  {
    "name": "Norfolk Island",
    "code": "NF",
    "countryName": "Norfolk Island",
    "dialCode": "+672",
  },
  {
    "name": "Northern Mariana Islands",
    "code": "MP",
    "countryName": "Northern Mariana Islands",
    "dialCode": "+1670",
  },
  {
    "name": "Norge",
    "code": "NO",
    "countryName": "Norway",
    "dialCode": "+47",
  },
  {
    "name": "عمان",
    "code": "OM",
    "countryName": "Oman",
    "dialCode": "+968",
  },
  {
    "name": "Pakistan",
    "code": "PK",
    "countryName": "Oman",
    "dialCode": "+92",
  },
  {
    "name": "Palau",
    "code": "PW",
    "countryName": "Palau",
    "dialCode": "+680",
  },
  {
    "name": "فلسطين",
    "code": "PS",
    "countryName": "Palestine",
    "dialCode": "+970",
  },
  {
    "name": "Panamá",
    "code": "PA",
    "countryName": "Panama",
    "dialCode": "+507",
  },
  {
    "name": "Papua Niugini",
    "code": "PG",
    "countryName": "Papua New Guinea",
    "dialCode": "+675",
  },
  {
    "name": "Paraguay",
    "code": "PY",
    "countryName": "Paraguay",
    "dialCode": "+595",
  },
  {
    "name": "Perú",
    "code": "PE",
    "countryName": "Peru",
    "dialCode": "+51",
  },
  {
    "name": "Pilipinas",
    "code": "PH",
    "countryName": "Philippines",
    "dialCode": "+63",
  },
  {
    "name": "Pitcairn Islands",
    "code": "PN",
    "countryName": "Pitcairn Islands",
    "dialCode": "+64",
  },
  {
    "name": "Polska",
    "code": "PL",
    "countryName": "Poland",
    "dialCode": "+48",
  },
  {
    "name": "Portugal",
    "code": "PT",
    "countryName": "Portugal",
    "dialCode": "+351",
  },
  {
    "name": "Puerto Rico",
    "code": "PR",
    "countryName": "The Commonwealth of Puerto Rico",
    "dialCode": "+1939",
  },
  {
    "name": "Puerto Rico",
    "code": "PR",
    "countryName": "The Commonwealth of Puerto Rico",
    "dialCode": "+1787",
  },
  {
    "name": "قطر",
    "code": "QA",
    "countryName": "Qatar",
    "dialCode": "+974",
  },
  {
    "name": "România",
    "code": "RO",
    "countryName": "Romania",
    "dialCode": "+40",
  },
  {
    "name": "Россия",
    "code": "RU",
    "countryName": "Russia",
    "dialCode": "+7",
  },
  {
    "name": "Rwanda",
    "code": "RW",
    "countryName": "Rwanda",
    "dialCode": "+250",
  },
  {
    "name": "La Réunion",
    "code": "RE",
    "countryName": "Reunion",
    "dialCode": "+262",
  },
  {
    "name": "Saint-Barthélemy",
    "code": "BL",
    "countryName": "Saint Barthélemy",
    "dialCode": "+590",
  },
  {
    "name": "Saint Helena",
    "code": "SH",
    "countryName": "Saint Helena",
    "dialCode": "+290",
  },
  {
    "name": "Saint Kitts and Nevis",
    "code": "KN",
    "countryName": "Saint Kitts and Nevis",
    "dialCode": "+1869",
  },
  {
    "name": "Saint Lucia",
    "code": "LC",
    "countryName": "Saint Lucia",
    "dialCode": "+1758",
  },
  {
    "name": "Saint-Martin",
    "code": "MF",
    "countryName": "Saint Barthélemy",
    "dialCode": "+590",
  },
  {
    "name": "Saint-Pierre-et-Miquelon",
    "code": "PM",
    "countryName": "Saint Pierre and Miquelon",
    "dialCode": "+508",
  },
  {
    "name": "Saint Vincent and the Grenadines",
    "code": "VC",
    "countryName": "Saint Vincent and the Grenadines",
    "dialCode": "+1784",
  },
  {
    "name": "Samoa",
    "code": "WS",
    "countryName": "Samoa",
    "dialCode": "+685",
  },
  {
    "name": "San Marino",
    "code": "SM",
    "countryName": "San Marino",
    "dialCode": "+378",
  },
  {
    "name": "São Tomé e Príncipe",
    "code": "ST",
    "countryName": "Sao Tome and Principe",
    "dialCode": "+239",
  },
  {
    "name": "العربية السعودية",
    "code": "SA",
    "countryName": "Saudi Arabia	",
    "dialCode": "+966",
  },
  {
    "name": "Sénégal",
    "code": "SN",
    "countryName": "Senegal",
    "dialCode": "+221",
  },
  {
    "name": "Србија",
    "code": "RS",
    "countryName": "Serbia and Montenegro	",
    "dialCode": "+381",
  },
  {
    "name": "Seychelles",
    "code": "SC",
    "countryName": "Seychelles",
    "dialCode": "+248",
  },
  {
    "name": "Sierra Leone",
    "code": "SL",
    "countryName": "Sierra Leone",
    "dialCode": "+232",
  },
  {
    "name": "Singapore",
    "code": "SG",
    "countryName": "Singapore",
    "dialCode": "+65",
  },
  {
    "name": "Slovensko",
    "code": "SK",
    "countryName": "Slovakia",
    "dialCode": "+421",
  },
  {
    "name": "Slovenija",
    "code": "SI",
    "countryName": "Slovenia",
    "dialCode": "+386",
  },
  {
    "name": "Solomon Islands",
    "code": "SB",
    "countryName": "Solomon Islands	",
    "dialCode": "+677",
  },
  {
    "name": "Soomaaliya",
    "code": "SO",
    "countryName": "Somalia",
    "dialCode": "+252",
  },
  {
    "name": "South Africa",
    "code": "ZA",
    "countryName": "South Africa	",
    "dialCode": "+27",
  },
  {
    "name": "South Sudan",
    "code": "SS",
    "countryName": "South Sudan",
    "dialCode": "+211",
  },
  {
    "name": "South Georgia",
    "code": "GS",
    "countryName": "South Georgia",
    "dialCode": "+500",
  },
  {
    "name": "España",
    "code": "ES",
    "countryName": "Spain",
    "dialCode": "+34",
  },
  {
    "name": "Sri Lanka",
    "code": "LK",
    "countryName": "Sri Lanka",
    "dialCode": "+94",
  },
  {
    "name": "السودان",
    "code": "SD",
    "countryName": "Sudan",
    "dialCode": "+249",
  },
  {
    "name": "Suriname",
    "code": "SR",
    "countryName": "Suriname",
    "dialCode": "+597",
  },
  {
    "name": "Svalbard og Jan Mayen",
    "code": "SJ",
    "countryName": "Svalbard",
    "dialCode": "+47",
  },
  {
    "name": "Swaziland",
    "code": "SZ",
    "countryName": "Swaziland",
    "dialCode": "+268",
  },
  {
    "name": "Sverige",
    "code": "SE",
    "countryName": "Sweden",
    "dialCode": "+46",
  },
  {
    "name": "Schweiz",
    "code": "CH",
    "countryName": "Switzerland",
    "dialCode": "+41",
  },
  {
    "name": "سوريا",
    "code": "SY",
    "countryName": "Syria",
    "dialCode": "+963",
  },
  {
    "name": "中国台湾",
    "code": "TW",
    "countryName": "Taiwan",
    "dialCode": "+886",
  },
  {
    "name": "Тоҷикистон",
    "code": "TJ",
    "countryName": "Tajikistan",
    "dialCode": "+992",
  },
  {
    "name": "Tanzania",
    "code": "TZ",
    "countryName": "Tanzania",
    "dialCode": "+255",
  },
  {
    "name": "ประเทศไทย",
    "code": "TH",
    "countryName": "Thailand",
    "dialCode": "+66",
  },
  {
    "name": "Timor-Leste",
    "code": "TL",
    "countryName": "Democratic Republic of Timor-Leste",
    "dialCode": "+670",
  },
  {
    "name": "Togo",
    "code": "TG",
    "countryName": "Togo",
    "dialCode": "+228",
  },
  {
    "name": "Tokelau",
    "code": "TK",
    "countryName": "Tokelau",
    "dialCode": "+690",
  },
  {
    "name": "Tonga",
    "code": "TO",
    "countryName": "Tonga",
    "dialCode": "+676",
  },
  {
    "name": "Trinidad and Tobago",
    "code": "TT",
    "countryName": "Trinidad and Tobago	",
    "dialCode": "+1868",
  },
  {
    "name": "تونس",
    "code": "TN",
    "countryName": "Tunisia",
    "dialCode": "+216",
  },
  {
    "name": "Türkiye",
    "code": "TR",
    "countryName": "Turkey",
    "dialCode": "+90",
  },
  {
    "name": "Türkmenistan",
    "code": "TM",
    "countryName": "Turkmenistan",
    "dialCode": "+993",
  },
  {
    "name": "Turks and Caicos Islands",
    "code": "TC",
    "countryName": "Turks and Caicos Islands	",
    "dialCode": "+1649",
  },
  {
    "name": "Tuvalu",
    "code": "TV",
    "countryName": "Tuvalu",
    "dialCode": "+688",
  },
  {
    "name": "Uganda",
    "code": "UG",
    "countryName": "Uganda",
    "dialCode": "+256",
  },
  {
    "name": "Україна",
    "code": "UA",
    "countryName": "Ukraine",
    "dialCode": "+380",
  },
  {
    "name": "دولة الإمارات العربية المتحدة",
    "code": "AE",
    "countryName": "United Arab Emirates",
    "dialCode": "+971",
  },
  {
    "name": "United Kingdom",
    "code": "GB",
    "countryName": "United Kingdom",
    "dialCode": "+44",
  },
  {
    "name": "United States",
    "code": "US",
    "countryName": "United States",
    "dialCode": "+1",
  },
  {
    "name": "Uruguay",
    "code": "UY",
    "countryName": "Uruguay",
    "dialCode": "+598",
  },
  {
    "name": "O‘zbekiston",
    "code": "UZ",
    "countryName": "Uzbekistan",
    "dialCode": "+998",
  },
  {
    "name": "Vanuatu",
    "code": "VU",
    "countryName": "Vanuatu",
    "dialCode": "+678",
  },
  {
    "name": "Venezuela",
    "code": "VE",
    "countryName": "Venezuela",
    "dialCode": "+58",
  },
  {
    "name": "Việt Nam",
    "code": "VN",
    "countryName": "Vietnam",
    "dialCode": "+84",
  },
  {
    "name": "British Virgin Islands",
    "code": "VG",
    "countryName": "British Virgin Islands",
    "dialCode": "+1284",
  },
  {
    "name": "United States Virgin Islands",
    "code": "VI",
    "countryName": "Virgin Islands",
    "dialCode": "+1340",
  },
  {
    "name": "Wallis et Futuna",
    "code": "WF",
    "countryName": "Wallis and Futuna	",
    "dialCode": "+681",
  },
  {
    "name": "اليَمَن",
    "code": "YE",
    "countryName": "Yemen",
    "dialCode": "+967",
  },
  {
    "name": "Zambia",
    "code": "ZM",
    "countryName": "Zambia",
    "dialCode": "+260",
  },
  {
    "name": "Zimbabwe",
    "code": "ZW",
    "countryName": "Zimbabwe",
    "dialCode": "+263",
  },
];
